==> uix-kit-3.6.32.tgz: package/src/components/ES6/_app-load-rtl.js <==
/*
 * Import RTL SASS files from components
 *
 * !!! Note 1: In RTL mode, only rtl style files are generated independently.
 * !!! Note 2: These RTL modules do not need JavaScript.
 *    
 */

/******/
/******/
/* base */
import '@uixkit/core/_global/scss-rtl/_style.scss';



/******/
/******/
/* pages */
import '@uixkit/core/advanced-slider/scss-rtl/_basic.scss';
import '@uixkit/core/advanced-slider/scss-rtl/_special.scss';
import '@uixkit/core/card/scss-rtl/_style.scss';
import '@uixkit/core/content-placeholder-animated/scss-rtl/_style.scss';
import '@uixkit/core/dropdown-menu/scss-rtl/_style.scss';
import '@uixkit/core/flexslider/scss-rtl/_style.scss';
import '@uixkit/core/form/scss-rtl/_style.scss';
import '@uixkit/core/lightbox/scss-rtl/_style.scss';
import '@uixkit/core/list-brands/scss-rtl/_style.scss';
import '@uixkit/core/list-bulleted/scss-rtl/_style.scss';
import '@uixkit/core/list-maintain-aspect-ratio/scss-rtl/_style.scss';
import '@uixkit/core/list-side-by-side/scss-rtl/_style.scss';
import '@uixkit/core/login-templates/scss-rtl/_style.scss';
import '@uixkit/core/modal-dialog/scss-rtl/_style.scss';
import '@uixkit/core/ribbon/scss-rtl/_style.scss';
import '@uixkit/core/single-post/scss-rtl/_style.scss';
import '@uixkit/core/striking/scss-rtl/_style.scss';
import '@uixkit/core/table/scss-rtl/_style.scss';
import '@uixkit/core/tooltip/scss-rtl/_style.scss';
import '@uixkit/core/vertical-menu/scss-rtl/_style.scss';
import '@uixkit/core/wordpress/scss-rtl/_wp_core.scss';

==> uix-kit-3.7.5.tgz: package/src/components/ES6/_app-load-rtl.js <==
/*
 * Import RTL SASS files from components
 *
 * !!! Note 1: In RTL mode, only rtl style files are generated independently.
 * !!! Note 2: These RTL modules do not need JavaScript.
 *    
 */

/******/
/******/
/* base */
import '@uixkit/core/_global/scss-rtl/_style.scss';



/******/
/******/
/* pages */
import '@uixkit/core/advanced-slider/scss-rtl/_basic.scss';
import '@uixkit/core/advanced-slider/scss-rtl/_special.scss';
import '@uixkit/core/card/scss-rtl/_style.scss';
import '@uixkit/core/content-placeholder-animated/scss-rtl/_style.scss';
import '@uixkit/core/dropdown-menu/scss-rtl/_style.scss';
import '@uixkit/core/flexslider/scss-rtl/_style.scss';
import '@uixkit/core/form/scss-rtl/_basic.scss';
import '@uixkit/core/form/scss-rtl/_theme_material.scss';
import '@uixkit/core/form/scss-rtl/_3rd_party_plugins.scss';
import '@uixkit/core/lightbox/scss-rtl/_style.scss';
import '@uixkit/core/list-brands/scss-rtl/_style.scss';
import '@uixkit/core/list-bulleted/scss-rtl/_style.scss';
import '@uixkit/core/list-maintain-aspect-ratio/scss-rtl/_style.scss';
import '@uixkit/core/list-side-by-side/scss-rtl/_style.scss';
import '@uixkit/core/login-templates/scss-rtl/_style.scss';
import '@uixkit/core/modal-dialog/scss-rtl/_style.scss';
import '@uixkit/core/ribbon/scss-rtl/_style.scss';
import '@uixkit/core/single-post/scss-rtl/_style.scss';
import '@uixkit/core/striking/scss-rtl/_style.scss';
import '@uixkit/core/table/scss-rtl/_style.scss';
import '@uixkit/core/tooltip/scss-rtl/_style.scss';
import '@uixkit/core/vertical-menu/scss-rtl/_style.scss';
import '@uixkit/core/wordpress/scss-rtl/_wp_core.scss';
